aind\_data\_schema.behavior package
===================================

Submodules
----------

aind\_data\_schema.behavior.behavior\_rig module
------------------------------------------------

.. automodule:: aind_data_schema.behavior.behavior_rig
   :members:
   :undoc-members:
   :show-inheritance:

aind\_data\_schema.behavior.behavior\_session module
----------------------------------------------------

.. automodule:: aind_data_schema.behavior.behavior_session
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: aind_data_schema.behavior
   :members:
   :undoc-members:
   :show-inheritance:
